/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NotificationComponent } from "./notification.component";
import { NotificationContainerComponent } from "./notification.container.component";
/**
 * Use this utility array to access all `@progress/kendo-angular-notification`-related components and directives in a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_NOTIFICATION } from '@progress/kendo-angular-notification';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_NOTIFICATION, KENDO_BUTTON],
 *   template: `<button kendoButton (click)="show()">Save data</button>`
 * })
 * export class AppComponent {
 *   constructor(private notificationService: NotificationService) {}
 *
 *   public show(): void {
 *     this.notificationService.show({
 *       content: 'Data saved successfully',
 *     });
 *   }
 * }
 * ```
 */
export declare const KENDO_NOTIFICATION: readonly [typeof NotificationComponent, typeof NotificationContainerComponent];
