/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, TemplateRef, ChangeDetectorRef, ViewContainerRef, ElementRef, OnInit, ComponentRef, OnDestroy, Renderer2 } from '@angular/core';
import { AnimationBuilder } from '@angular/animations';
import { Subscription } from 'rxjs';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { Type } from './models/type';
import { Animation } from './models/animation';
import * as i0 from "@angular/core";
/**
 * @hidden
 *
 */
export declare class NotificationComponent implements OnInit, OnDestroy {
    cdr: ChangeDetectorRef;
    private element;
    private renderer;
    private builder;
    private localizationService;
    /**
     * @hidden
     */
    xIcon: SVGIcon;
    contentId: string;
    container: ViewContainerRef;
    closeClickSubscription: Subscription;
    close: EventEmitter<any>;
    templateRef?: TemplateRef<any>;
    templateString?: string;
    width?: number;
    height?: number;
    notificationLabel: string;
    cssClass?: string | Array<string> | Object;
    hideAfter?: number;
    closable?: boolean;
    type?: Type;
    animation?: Animation;
    closeTitle: string;
    /**
     * @hidden
     */
    direction: string;
    get closeButtonTitle(): string;
    private defaultHideAfter;
    private hideTimeout;
    private animationEnd;
    private dynamicRTLSubscription;
    private rtl;
    constructor(cdr: ChangeDetectorRef, element: ElementRef, renderer: Renderer2, builder: AnimationBuilder, localizationService: LocalizationService);
    notificationClasses(): string;
    ngOnInit(): void;
    ngOnDestroy(): void;
    ngAfterViewInit(): void;
    typeClass(): string;
    typeIconClass(): string;
    typeSVGIcon(): SVGIcon;
    onCloseClick(): void;
    hide(customComponent?: ComponentRef<any>): void;
    private setHideTimeout;
    private emitClose;
    private play;
    private animate;
    private slideAnimation;
    private fadeAnimation;
    static ɵfac: i0.ɵɵFactoryDeclaration<NotificationComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NotificationComponent, "kendo-notification", never, { "templateRef": { "alias": "templateRef"; "required": false; }; "templateString": { "alias": "templateString"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "notificationLabel": { "alias": "notificationLabel"; "required": false; }; "cssClass": { "alias": "cssClass"; "required": false; }; "hideAfter": { "alias": "hideAfter"; "required": false; }; "closable": { "alias": "closable"; "required": false; }; "type": { "alias": "type"; "required": false; }; "animation": { "alias": "animation"; "required": false; }; }, {}, never, never, true, never>;
}
